#
# spec file for package libreoffice-openclipart
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           libreoffice-openclipart
Url:            http://www.documentfoundation.org/
# We use the gengal in the headles mode; it was added in OpenOffice_org-2.2.99.221
BuildRequires:  libreoffice >= 3.3.98
BuildRequires:  openclipart-svg
%if 0%{?suse_version} == 01010
BuildRequires:  update-alternatives
%endif
%if 0%{?suse_version} > 01000 || 0%{?meego_version}
%define 	openclipart_dir %_datadir/clipart/openclipart
%else
%define 	openclipart_dir %_datadir/openclipart
%endif
%define 	ooo_home 	libreoffice
%define 	ooo_basis	basis3.4
# OOo uses ugly names for galleries (std_prefix + index + std_suffix)
# The openlipart gallery should start from the index 70
%define		gal_num_from 	70
License:        GPLv2+ ; LGPLv2.1+
Summary:        Extra Galleries for LibreOffice
Group:          Productivity/Office/Suite
Version:        3.4
Release:        1.3.1
AutoReqProv:    on
# OOo-2.x with link-to-ooo-home script is required
Requires:       libreoffice >= 3.3.98
Requires:       libreoffice-filters-optional >= 3.3.98
# this package includes only thumbnails, the original clipart is still neeeded
%requires_eq  openclipart-svg
%if 0%{?suse_version}
Supplements:    packageand(openclipart-svg:libreoffice) packageand(openclipart-svg:OpenOffice_org)
%endif
# compat stuff
# we want to obsolete OpenOffice_org-openclipart to achieve a smooth update
Provides:       OpenOffice_org-openclipart = %version
Obsoletes:      OpenOffice_org-openclipart <= %version
Provides:       OpenOffice_org-galleries = %version
Provides:       OpenOffice_org2-galleries = %version
Obsoletes:      OpenOffice_org-galleries < %version
Obsoletes:      OpenOffice_org2-galleries < %version
Source:         libreoffice-openclipart.blacklist
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
This package contains an extensive set of extra galleries for
LibreOffice. It can be used to enrich documents with graphics arts.



%prep
%setup -T -c
cp %{S:0} .

%build
for prefix in /usr/lib /usr/lib64 ; do
    if test -x $prefix/%ooo_home/program/gengal ; then
	GENGAL_BIN=$prefix/%ooo_home/program/gengal
	break
    fi
done
test -z "$GENGAL_BIN" && { echo '$GENGAL_BIN not set' >&2 ; exit 1; }
#
for dir in `find -L %openclipart_dir -mindepth 1 -maxdepth 1 -type d | LC_CTYPE=C sort` ; do
	# get the gallery name from the directory name
	# and make the first character uppercase
	dirname=${dir##*/}
	gal_name=$dirname
	gal_name=`echo $gal_name | tr "_-" "  "`
	gal_name_rest=${gal_name#?}
	gal_name_first_char=${gal_name%$gal_name_rest}
	gal_name_first_char=`echo $gal_name_first_char | tr "a-z" "A-Z"`
	gal_name=$gal_name_first_char$gal_name_rest
	#
	echo "Doing gallery $gal_name..."
	#
	# add too big files to the black list (svg import is somewhat slow)
	blacklist=`mktemp /tmp/gengal.blacklist.XXXXXX`
	IFS_saved="$IFS"
IFS="
"
	for file in `find $dir -name "*.svg" | LC_CTYPE=C sort` ; do
	    test -L $file && echo "$file" >>$blacklist
	    echo size=`du -L $file | cut -f1`
	    test `du -b -L $file  | cut -f1` -gt 100000 && echo "$file" >>$blacklist
	done
	IFS="$IFS_saved"
	# add files from explicit blacklist if any
	grep "^$dirname" libreoffice-openclipart.blacklist >>$blacklist || true
	echo "Ignoring too big and problematic files:"
	cat $blacklist
	echo "Enf of the list"
	#
	# xargs is necessary because the list of files is quite long
	find $dir -name "*.svg" -print0 | \
	LC_CTYPE=C sort -z | \
	grep -z -v -f $blacklist | \
	{ xargs -0 $GENGAL_BIN -headless  --name "$gal_name" --path $RPM_BUILD_DIR/%name-%version --number-from "%gal_num_from" || exit 1; }
	rm $blacklist
done

%install
# FIXME: The stuff from this directory is linked to ooo-home by the script
#        link-to-ooo-home; so it must keep the usual OOo structure
install -m 755 -d $RPM_BUILD_ROOT%_datadir/%ooo_home/%ooo_basis/share/gallery
# compat stuff
install -m 755 -d $RPM_BUILD_ROOT%_datadir/ooo3/%ooo_basis/share/gallery
for file in `ls sg*` ; do
    install -m 644 $file $RPM_BUILD_ROOT%_datadir/%ooo_home/%ooo_basis/share/gallery
    echo "%_datadir/%ooo_home/%ooo_basis/share/gallery/$file" >>$RPM_BUILD_ROOT%_datadir/%ooo_home/openclipart_list.txt
    # compat stuff
    ln -sf ../../../../%ooo_home/%ooo_basis/share/gallery/$file $RPM_BUILD_ROOT%_datadir/ooo3/%ooo_basis/share/gallery
    echo "%_datadir/ooo3/%ooo_basis/share/gallery/$file" >>$RPM_BUILD_ROOT%_datadir/%ooo_home/openclipart_list.txt
done
echo "%dir %_datadir/%ooo_home/"				>>$RPM_BUILD_ROOT%_datadir/%ooo_home/openclipart_list.txt
echo "%dir %_datadir/%ooo_home/%ooo_basis"			>>$RPM_BUILD_ROOT%_datadir/%ooo_home/openclipart_list.txt
echo "%dir %_datadir/%ooo_home/%ooo_basis/share"		>>$RPM_BUILD_ROOT%_datadir/%ooo_home/openclipart_list.txt
echo "%dir %_datadir/%ooo_home/%ooo_basis/share/gallery"	>>$RPM_BUILD_ROOT%_datadir/%ooo_home/openclipart_list.txt
# compat stuff
echo "%dir %_datadir/ooo3/"				>>$RPM_BUILD_ROOT%_datadir/%ooo_home/openclipart_list.txt
echo "%dir %_datadir/ooo3/%ooo_basis"			>>$RPM_BUILD_ROOT%_datadir/%ooo_home/openclipart_list.txt
echo "%dir %_datadir/ooo3/%ooo_basis/share"		>>$RPM_BUILD_ROOT%_datadir/%ooo_home/openclipart_list.txt
echo "%dir %_datadir/ooo3/%ooo_basis/share/gallery"	>>$RPM_BUILD_ROOT%_datadir/%ooo_home/openclipart_list.txt

%clean
rm -rf $RPM_BUILD_ROOT

%post
%_datadir/%ooo_home/link-to-ooo-home %_datadir/%ooo_home/openclipart_list.txt || true

%preun
test "$1" = "0" && %_datadir/%ooo_home/link-to-ooo-home --unlink %_datadir/%ooo_home/openclipart_list.txt || true

%files
%defattr(-, root, root)
%dir %_datadir/%ooo_home
%_datadir/%ooo_home/openclipart_list.txt
%dir %_datadir/%ooo_home/%ooo_basis
%dir %_datadir/%ooo_home/%ooo_basis/share
%dir %_datadir/%ooo_home/%ooo_basis/share/gallery
%_datadir/%ooo_home/%ooo_basis/share/gallery/*
# compat stuff
%dir %_datadir/ooo3
%dir %_datadir/ooo3/%ooo_basis
%dir %_datadir/ooo3/%ooo_basis/share
%dir %_datadir/ooo3/%ooo_basis/share/gallery
%_datadir/ooo3/%ooo_basis/share/gallery/*

%changelog
* Tue Sep 13 2011 pmladek@suse.com
- maintenance update (bnc#704311, MaintenanceTracker-43152)
* Wed Aug  3 2011 pmladek@novell.com
- updated basis dir to basis3.4
- updated dependencies on LO >= 3.3.98
- fixed search for gengal binary; was moved from
  libreoffice/basis-link/program to libreoffice/program
* Fri Feb 18 2011 pmladek@suse.cz
- bumped version to make sure that it is considered as a replacement
  of the older package
* Fri Feb  4 2011 suse-beta@cboltz.de
- added error check to avoid later cryptic failure
* Thu Feb  3 2011 pmladek@suse.cz
- renamed from OpenOffice_org-openclipart to libreoffice-openclipart
- added supplements packageand(openclipart-svg:libreoffice)
  to make it installed with libreoffice (bnc#668145)
- installed files into /usr/share/libreoffice; added compat symlinks
  into the older location /usr/share/ooo3
* Tue Sep 21 2010 pmladek@suse.cz
- updated basis dir to basis3.3
- update dependencies on OOo >= 3.2.98
* Wed May 19 2010 pmladek@suse.cz
- added initial support for build on MeeGo distro
* Fri Mar 26 2010 pmladek@suse.cz
- added decorations/celticknotwork_trianglesimple_01.svg to fix build
  in openSUSE:Factory
* Mon Nov  9 2009 pmladek@suse.cz
- updated basis dir to basis3.2
- update dependencies on OOo >= 3.1.98
- added few more packages on the blacklist to fix build on openSUSE-11.2
* Mon Mar 16 2009 pmladek@suse.cz
- added back OpenOffice_org-filters-optional to BuildRequires and
  Requires because we switched to the split build in BS
* Fri Feb 27 2009 pmladek@suse.cz
- updated basis dir to basis3.1
- update dependencies on OOo >= 3.0.99
* Wed Nov 12 2008 pmladek@suse.cz
- added update-alternatives to BuildRequires for SLED10; it fixes
  an xerces-j2 dependency problem
* Tue Nov 11 2008 pmladek@suse.cz
- fixed dependency against the non-split build
* Fri Nov  7 2008 pmladek@suse.cz
- switched to the openclipart-svg sources
- added OpenOffice_org-filters-optional to BuildRequires and Requires;
  it includes the SVG import filter for OOo
- added too big and some problematic files on the blacklist
- updated to the version 3 to be in sync with OpenOffice_org
* Fri Aug 15 2008 pmladek@suse.cz
- added Supplements: packageand(openclipart:OpenOffice_org) (bnc#168589)
* Mon Jul 21 2008 pmladek@suse.cz
- updated for OOo-3.0 (prefixes, dependency)
* Tue Jul 24 2007 pmladek@suse.cz
- split from the OpenOffice_org-2.2.99.221 source package [n#284980]
- renamed from OpenOffice_org-galleries to OpenOffice_org-openclipart
- used version 2 (should work for all OOo-2.x packages)
- used gengal in the headless mode; it was a feature added in
  OpenOffice_org-2.2.99.221
